@@ -6,7 +6,7 @@ from airflow.exceptions import AirflowException
 from airflow.utils.state import State
 from dagster_airflow.vendor.kubernetes_pod_operator import KubernetesPodOperator
 from dagster_graphql.client.query import RAW_EXECUTE_PLAN_MUTATION
-from dagster_graphql.client.util import construct_variables, parse_raw_log_lines
+from dagster_graphql.client.util import construct_execute_plan_variables, parse_raw_log_lines
 
 from dagster import __version__ as dagster_version
 from dagster import seven
@@ -94,7 +94,7 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
 
     @property
     def query(self):
-        variables = construct_variables(
+        variables = construct_execute_plan_variables(
             self.recon_repo,
             self.mode,
             self.run_config,
