@@ -8,29 +8,31 @@ from airflow.utils import timezone
 from dagster_airflow.factory import (
     AIRFLOW_MAX_DAG_NAME_LEN,
     _rename_for_airflow,
-    make_airflow_dag_for_handle,
+    make_airflow_dag_for_recon_repo,
 )
 from dagster_airflow.test_fixtures import (  # pylint: disable=unused-import
     dagster_airflow_python_operator_pipeline,
     execute_tasks_in_dag,
 )
-from dagster_airflow_tests.conftest import environments_path  # pylint: disable=unused-import
-from dagster_airflow_tests.marks import nettest
+from dagster_airflow_tests.marks import nettest, requires_airflow_db
+from dagster_test.test_project import test_project_environments_path
 
-from dagster import ExecutionTargetHandle
+from dagster.core.definitions.reconstructable import ReconstructableRepository
 from dagster.core.utils import make_new_run_id
 from dagster.utils import load_yaml_from_glob_list
 
 from .utils import validate_pipeline_execution, validate_skip_pipeline_execution
 
 
+@requires_airflow_db
 def test_fs_storage_no_explicit_base_dir(
-    dagster_airflow_python_operator_pipeline, environments_path,
+    dagster_airflow_python_operator_pipeline,
 ):  # pylint: disable=redefined-outer-name
     pipeline_name = 'demo_pipeline'
+    environments_path = test_project_environments_path()
     results = dagster_airflow_python_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_filesystem_no_explicit_base_dir.yaml'),
@@ -39,13 +41,15 @@ def test_fs_storage_no_explicit_base_dir(
     validate_pipeline_execution(results)
 
 
+@requires_airflow_db
 def test_fs_storage(
-    dagster_airflow_python_operator_pipeline, environments_path,
+    dagster_airflow_python_operator_pipeline,
 ):  # pylint: disable=redefined-outer-name
     pipeline_name = 'demo_pipeline'
+    environments_path = test_project_environments_path()
     results = dagster_airflow_python_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_filesystem.yaml'),
@@ -55,13 +59,15 @@ def test_fs_storage(
 
 
 @nettest
+@requires_airflow_db
 def test_s3_storage(
-    dagster_airflow_python_operator_pipeline, environments_path,
+    dagster_airflow_python_operator_pipeline,
 ):  # pylint: disable=redefined-outer-name
     pipeline_name = 'demo_pipeline'
+    environments_path = test_project_environments_path()
     results = dagster_airflow_python_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_s3.yaml'),
@@ -71,13 +77,15 @@ def test_s3_storage(
 
 
 @nettest
+@requires_airflow_db
 def test_gcs_storage(
-    dagster_airflow_python_operator_pipeline, environments_path,
+    dagster_airflow_python_operator_pipeline,
 ):  # pylint: disable=redefined-outer-name
     pipeline_name = 'demo_pipeline_gcs'
+    environments_path = test_project_environments_path()
     results = dagster_airflow_python_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_gcs.yaml'),
@@ -86,18 +94,21 @@ def test_gcs_storage(
     validate_pipeline_execution(results)
 
 
+@requires_airflow_db
 def test_skip_operator(
-    dagster_airflow_python_operator_pipeline, environments_path,
+    dagster_airflow_python_operator_pipeline,
 ):  # pylint: disable=redefined-outer-name
     pipeline_name = 'optional_outputs'
+    environments_path = test_project_environments_path()
     results = dagster_airflow_python_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name),
         environment_yaml=[os.path.join(environments_path, 'env_filesystem.yaml')],
     )
     validate_skip_pipeline_execution(results)
 
 
+@requires_airflow_db
 def test_rename_for_airflow():
     pairs = [
         ('foo', 'foo'),
@@ -114,16 +125,18 @@ def test_rename_for_airflow():
         assert after == _rename_for_airflow(before)
 
 
-def test_error_dag_python(environments_path):  # pylint: disable=redefined-outer-name
+@requires_airflow_db
+def test_error_dag_python():  # pylint: disable=redefined-outer-name
     pipeline_name = 'demo_error_pipeline'
-    handle = ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name)
+    recon_repo = ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name)
+    environments_path = test_project_environments_path()
     environment_yaml = [
         os.path.join(environments_path, 'env_filesystem.yaml'),
     ]
-    environment_dict = load_yaml_from_glob_list(environment_yaml)
+    run_config = load_yaml_from_glob_list(environment_yaml)
     execution_date = timezone.utcnow()
 
-    dag, tasks = make_airflow_dag_for_handle(handle, pipeline_name, environment_dict)
+    dag, tasks = make_airflow_dag_for_recon_repo(recon_repo, pipeline_name, run_config)
 
     with pytest.raises(AirflowException) as exc_info:
         execute_tasks_in_dag(dag, tasks, run_id=make_new_run_id(), execution_date=execution_date)
